@@ -28,6 +28,8 @@ else:
     rows_written = 0
     seen_outfile = set()
     for batch in splitter.next_batch():
+        print(batch)
+
         outfile = os.path.join(args.outdir,batch["table_name"] + ".tsv")
         if os.path.exists(outfile) and outfile not in seen_outfile:
             os.remove(outfile)
@@ -37,6 +39,6 @@ else:
         with open(outfile,"a") as fh_out:
             rows_written += len(batch["rows"])
             for r in batch["rows"]:
-                fh_out.write("\t".join(r) + "\n")
+                fh_out.write("\t".join(map(str, r)) + "\n")
             print("rows written: ",rows_written)
 
